==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/xml/classes/xmlelementjson.php <==
<?php
/**
 * stanislav.elbl, 10.06.2021 0:10
 */

namespace RonPortal\XML\Classes;

use Ron\StringUtils;

use RonPortal\XML\XMLFormElement;


class XMLElementJson extends XMLFormElement
{
    var $textContent;

    protected function loadXMLElement($xmlReader)
    {
        parent::loadXMLElement($xmlReader);

        $this ->textContent = StringUtils::fromUTF8($this ->loadXMLValue($xmlReader) );
    }


    function getHTMLOutput()
    {
        $varName = $this ->getAttributeValue('variable');
        $varName = $this ->nahradPromenne($varName);

        $name = $this->getAttributeValue('name'); // jmeno promenne v javascriptu

        $result = '';

        if ($this ->xmlForm ->jsonOutputObject) {
            // javascriptovy pozadavek
            if ($varName) {
                $this->xmlForm->jsonOutputObject->addData($name, $this->variableValue($varName));
            } else {
                $text = $this ->nahradPromenne($this ->textContent);
                $this ->xmlForm ->jsonOutputObject ->addText($name, $text);
            }

        } else {
            // generovani standardniho html
            if ($name) {
                $result .= $name . ' = ';
            }

            if ($varName) {
                $result .= json_encode( $this->variableValue($varName) );
            } else {
                $text = $this ->nahradPromenne($this ->textContent);
                $result .= json_encode( $text );
            }

            if ($name) {
                $result .= ';';
            }
        }

        return $result;
    }
}


/*
//DOC
PAGE json
<pre>
PRE
  <json name="jmeno_vytvorene_promenne" varname="jmeno_promenne_s_hodnotou">hodnota</json>
PREEND
</pre>

//END
*/

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/xml/classes/xmlelementjson.php <==
<?php
/**
 * stanislav.elbl, 10.06.2021 0:10
 */

namespace RonPortal\XML\Classes;

use Ron\StringUtils;

use RonPortal\XML\XMLFormElement;


class XMLElementJson extends XMLFormElement
{
    var $textContent;

    protected function loadXMLElement($xmlReader)
    {
        parent::loadXMLElement($xmlReader);

        $this ->textContent = StringUtils::fromUTF8($this ->loadXMLValue($xmlReader) );
    }


    function getHTMLOutput()
    {
        $varName = $this ->getAttributeValue('variable');
        $varName = $this ->nahradPromenne($varName);

        $name = $this->getAttributeValue('name'); // jmeno promenne v javascriptu

        $result = '';

        if ($this ->xmlForm ->jsonOutputObject) {
            // javascriptovy pozadavek
            if ($varName) {
                $this->xmlForm->jsonOutputObject->addData($name, $this->variableValue($varName));
            } else {
                $text = $this ->nahradPromenne($this ->textContent);
                $this ->xmlForm ->jsonOutputObject ->addText($name, $text);
            }

        } else {
            // generovani standardniho html
            if ($name) {
                $result .= $name . ' = ';
            }

            if ($varName) {
                $result .= json_encode( $this->variableValue($varName) );
            } else {
                $text = $this ->nahradPromenne($this ->textContent);
                $result .= json_encode( $text );
            }

            if ($name) {
                $result .= ';';
            }
        }

        return $result;
    }
}


/*
//DOC
PAGE json
<pre>
PRE
  <json name="jmeno_vytvorene_promenne" variable="jmeno_promenne_s_hodnotou">hodnota</json>
PREEND
</pre>

//END
*/
